# Create a virtual environment

It is highly recommended to work inside of a virtual environment.

- Use `venv` to create a virtual environment:
  ```bash
  python3 -m venv .venv
  ```
- Activate the virtual environment:
  ```bash
  source .venv/bin/activate
  ```
  If the activation is successfull, you'll see `(.venv)` at the beginning of the terminal.
